@@ -2,6 +2,8 @@ use std::collections::BTreeMap;
 use std::fmt;
 use std::str::FromStr;
 
+use crate::parameter::tokenize::tokenize;
+use crate::parameter::ParameterValue;
 use crate::{
     error::{OptionsError, ParameterScanError},
     parameter::{
@@ -12,9 +14,6 @@ use crate::{
 
 use clap::{parser::ValuesRef, ArgMatches};
 
-use crate::parameter::tokenize::tokenize;
-use crate::parameter::ParameterValue;
-
 use anyhow::{bail, Context, Result};
 use rust_decimal::Decimal;
 
@@ -59,6 +58,22 @@ impl<'a> Command<'a> {
         )
     }
 
+    pub fn get_name_with_unused_parameters(&self) -> String {
+        let parameters = self
+            .get_unused_parameters()
+            .fold(String::new(), |output, (parameter, value)| {
+                output + &format!("{parameter} = {value}, ")
+            });
+        let parameters = parameters.trim_end_matches(", ");
+        let parameters = if parameters.is_empty() {
+            "".into()
+        } else {
+            format!(" ({parameters})")
+        };
+
+        format!("{}{}", self.get_name(), parameters)
+    }
+
     pub fn get_command_line(&self) -> String {
         self.replace_parameters_in(self.expression)
     }
@@ -66,7 +81,7 @@ impl<'a> Command<'a> {
     pub fn get_command(&self) -> Result<std::process::Command> {
         let command_line = self.get_command_line();
         let mut tokens = shell_words::split(&command_line)
-            .with_context(|| format!("Failed to parse command '{}'", command_line))?
+            .with_context(|| format!("Failed to parse command '{command_line}'"))?
             .into_iter();
 
         if let Some(program_name) = tokens.next() {
@@ -82,14 +97,17 @@ impl<'a> Command<'a> {
         &self.parameters
     }
 
+    pub fn get_unused_parameters(&self) -> impl Iterator<Item = &(&'a str, ParameterValue)> {
+        self.parameters
+            .iter()
+            .filter(move |(parameter, _)| !self.expression.contains(&format!("{{{parameter}}}")))
+    }
+
     fn replace_parameters_in(&self, original: &str) -> String {
         let mut result = String::new();
         let mut replacements = BTreeMap::<String, String>::new();
         for (param_name, param_value) in &self.parameters {
-            replacements.insert(
-                format!("{{{param_name}}}", param_name = param_name),
-                param_value.to_string(),
-            );
+            replacements.insert(format!("{{{param_name}}}"), param_value.to_string());
         }
         let mut remaining = original;
         // Manually replace consecutive occurrences to avoid double-replacing: e.g.,
@@ -116,7 +134,7 @@ impl<'a> Command<'a> {
 pub struct Commands<'a>(Vec<Command<'a>>);
 
 impl<'a> Commands<'a> {
-    pub fn from_cli_arguments(matches: &'a ArgMatches) -> Result<Commands> {
+    pub fn from_cli_arguments(matches: &'a ArgMatches) -> Result<Commands<'a>> {
         let command_names = matches.get_many::<String>("command-name");
         let command_strings = matches
             .get_many::<String>("command")
@@ -233,8 +251,8 @@ impl<'a> Commands<'a> {
         self.0.iter()
     }
 
-    pub fn num_commands(&self) -> usize {
-        self.0.len()
+    pub fn num_commands(&self, has_reference_command: bool) -> usize {
+        self.0.len() + if has_reference_command { 1 } else { 0 }
     }
 
     /// Finds all the strings that appear multiple times in the input iterator, returning them in
@@ -299,7 +317,6 @@ impl<'a> Commands<'a> {
         let command_names = command_names.map_or(vec![], |names| {
             names.map(|v| v.as_str()).collect::<Vec<_>>()
         });
-        let command_strings = command_strings;
         let param_name = vals.next().unwrap().as_str();
         let param_min = vals.next().unwrap().as_str();
         let param_max = vals.next().unwrap().as_str();
@@ -366,7 +383,7 @@ fn test_get_parameterized_command_name() {
     assert_eq!(cmd.get_name(), "name-quux-baz");
 }
 
-impl<'a> fmt::Display for Command<'a> {
+impl fmt::Display for Command<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "{}", self.get_command_line())
     }
